/*
 * localTest
 *
 * This program shows the impact of setting LC_NUMERIC to a Qt program
 * (tested with Qt 4.8.5)
 * 
 * It shows that the impact is dependent on the transformation method of converting
 * a text into a number (double)
 *
 * 2014, Harald Nikolisin
 */
#include <iostream>
#include <locale.h>
#include <QApplication>
#include <QLabel>
#include <QLayout>
#include <QFile>
#include <QByteArray>
#include <QLocale>

#include "localeTest.h"

int main(int argc,char *argv[]){
  QApplication app(argc,argv);
  LocaleTest *lt = new LocaleTest();
  lt->show();
  return app.exec();
}

LocaleTest::LocaleTest(QWidget *parent) : QMainWindow(parent){
	mySystemLocale = new QLocale;
	QWidget* gridWidget = new QWidget(this);
	QGridLayout* gridLayout = new QGridLayout(gridWidget);
	gridLayout->setSpacing(20);
	gridLayout->addWidget(new QLabel("<b>Only Text</b>"),0,0);
	gridLayout->addWidget(new QLabel("<b>Double from QByteArray</b>"),0,1);
	gridLayout->addWidget(new QLabel("<b>Double from QString</b>"),0,2);
	gridLayout->addWidget(new QLabel("<b>Double from Locale</b>"),0,3);

	QFile in("numbers_latin15.txt");
	if(!in.open(QIODevice::ReadOnly|QIODevice::Text)){
		std::cerr << "File: " << in.fileName().toLocal8Bit().data() << " does not exist" << std::endl;
	}
	unsigned int i = 0;
	while(!in.atEnd()){
		QByteArray line = in.readLine();
		labDisplayText[i] = new QLabel(QString(line.trimmed().data()));
		gridLayout->addWidget(labDisplayText[i],i+1,0,1,1);
		bool ok;
		labDisplayDigitFromByteArray[i] = new QLabel(QString("%1").arg(line.trimmed().toDouble(&ok)));
		if(!ok) std::cerr << "Conversion of ByteArray " << line.trimmed().data() << " to double failed" << std::endl;
		gridLayout->addWidget(labDisplayDigitFromByteArray[i],i+1,1,1,1);
		labDisplayDigitFromString[i] = new QLabel(QString("%1").arg(QString(line).trimmed().toDouble(&ok)));
		if(!ok) std::cerr << "Conversion of QString " << QString(line).trimmed().data() << " to double failed" << std::endl;
		gridLayout->addWidget(labDisplayDigitFromString[i],i+1,2,1,1);
		labDisplayDigitFromLocale[i] = new QLabel(QString("%1").arg(mySystemLocale->toDouble(QString(line).trimmed(),&ok)));
		if(!ok) std::cerr << "Conversion of QLocale " << QString(line).trimmed().data() << " to double failed" << std::endl;
		gridLayout->addWidget(labDisplayDigitFromLocale[i],i+1,3,1,1);
		i++;
	}
	setCentralWidget(gridWidget);
}

